@@ -232,7 +232,8 @@ MANIFEST1_REQUIRED_HASH  = "MD5"
 # - Remove redundant settings from gentoo-x86/metadata/layout.conf.
 
 MANIFEST2_HASH_FUNCTIONS = ("SHA256", "SHA512", "WHIRLPOOL",
-		"BLAKE2B", "BLAKE2S", "SHA3_256", "SHA3_512")
+		"BLAKE2B", "BLAKE2S", "SHA3_256", "SHA3_512",
+		"STREEBOG256", "STREEBOG512")
 MANIFEST2_HASH_DEFAULTS = frozenset(["SHA256", "SHA512", "WHIRLPOOL"])
 MANIFEST2_REQUIRED_HASH  = "SHA256"
 
