@@ -13,7 +13,7 @@ import warnings
 
 import portage
 portage.proxy.lazyimport.lazyimport(globals(),
-	'portage.checksum:hashfunc_map,perform_multiple_checksums,' + \
+	'portage.checksum:get_valid_checksum_keys,perform_multiple_checksums,' + \
 		'verify_all,_apply_hash_filter,_filter_unaccelarated_hashes',
 	'portage.repository.config:_find_invalid_path_char',
 	'portage.util:write_atomic,writemsg_level',
@@ -129,7 +129,7 @@ class Manifest(object):
 	def __init__(self, pkgdir, distdir=None, fetchlist_dict=None,
 		manifest1_compat=DeprecationWarning, from_scratch=False, thin=False,
 		allow_missing=False, allow_create=True, hashes=None,
-		find_invalid_path_char=None):
+		find_invalid_path_char=None, strict_misc_digests=True):
 		""" Create new Manifest instance for package in pkgdir.
 		    Do not parse Manifest file if from_scratch == True (only for internal use)
 			The fetchlist_dict parameter is required only for generation of
@@ -154,7 +154,7 @@ class Manifest(object):
 
 		self.hashes.update(hashes.intersection(MANIFEST2_HASH_FUNCTIONS))
 		self.hashes.difference_update(hashname for hashname in \
-			list(self.hashes) if hashname not in hashfunc_map)
+			list(self.hashes) if hashname not in get_valid_checksum_keys())
 		self.hashes.add("size")
 		self.hashes.add(MANIFEST2_REQUIRED_HASH)
 		for t in MANIFEST2_IDENTIFIERS:
@@ -173,6 +173,7 @@ class Manifest(object):
 			self.guessType = guessManifestFileType
 		self.allow_missing = allow_missing
 		self.allow_create = allow_create
+		self.strict_misc_digests = strict_misc_digests
 
 	def getFullname(self):
 		""" Returns the absolute path to the Manifest file for this instance """
@@ -461,7 +462,8 @@ class Manifest(object):
 			fetchlist_dict=self.fetchlist_dict, from_scratch=True,
 			thin=self.thin, allow_missing=self.allow_missing,
 			allow_create=self.allow_create, hashes=self.hashes,
-			find_invalid_path_char=self._find_invalid_path_char)
+			find_invalid_path_char=self._find_invalid_path_char,
+			strict_misc_digests=self.strict_misc_digests)
 		pn = os.path.basename(self.pkgdir.rstrip(os.path.sep))
 		cat = self._pkgdir_category()
 
